==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/es_MX.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
    "Storage invalid" : "El almacenamiento es inválido",
    "Unknown error" : "Se presentó un error desconocido",
    "All files" : "Todos los archivos",
    "Recent" : "Reciente",
    "File could not be found" : "No fue posible encontrar el archivo",
    "Home" : "Inicio",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "No fue posible crear la carpeta \"{dir}\"",
    "Upload cancelled." : "Carga cancelada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No fue posible cargar {filename} ya que es una carpeta o tiene un tamaño de 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No tienes suficiente espacio disponible, Estas cargando {size1} pero sólo cuentas con {size2} disponible",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta destino \"{dir}\" ya no existe",
    "Not enough free space" : "No cuentas con suficiente espacio libre",
    "Uploading …" : "Cargando ...",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Target folder" : "Carpeta destino",
    "Delete" : "Borrar",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Unshare" : "Dejar de compartir",
    "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No fue posible determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
    "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n escondido","incluyendo %n ocultos"],
    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos"],
    "New" : "Nuevo",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El espacio de {owner} está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El espacio de {owner} está casi lleno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tu espacio está casi lleno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincide '{filter}'","coincidencia '{filter}'"],
    "View in folder" : "Ver en la carpeta",
    "Copied!" : "¡Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "New folder" : "Carpeta nueva",
    "Upload file" : "Cargar archivo",
    "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
    "Added to favorites" : "Agregado a los favoritos",
    "Removed from favorites" : "Eliminado de los favoritos",
    "You added {file} to your favorites" : "Agregaste {file} a tus favoritos",
    "You removed {file} from your favorites" : "Eliminaste {file} de tus favoritos",
    "File changes" : "Cambios al archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuario remoto\"",
    "You created {file}" : "Creaste {file}",
    "{user} created {file}" : "{user} creó {file}",
    "{file} was created in a public folder" : "{file} fue creado en una carpeta pública",
    "You changed {file}" : "Cambiaste {file}",
    "{user} changed {file}" : "{user} cambió {file}",
    "You deleted {file}" : "Borraste {file}",
    "{user} deleted {file}" : "{user} borró {file}",
    "You restored {file}" : "Restauraste {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Renombraste {oldfile} como {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renombró {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Moviste {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado </strong> o <strong>renombrado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>borrado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita las notificaciones de la creación y cambios a tus <strong>archivos favoritos</strong> <em>(sólo flujo)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Cargar (max. %s)",
    "File handling" : "Manejo de archivos",
    "Maximum upload size" : "Tamaño máximo de carga",
    "max. possible: " : "max. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tomar 5 minutos para que los cambios apliquen. ",
    "Missing permissions to edit from here." : "Faltan privilegios para editar desde aquí. ",
    "%s of %s used" : "%s de %s usado",
    "%s used" : "%s usado",
    "Settings" : "Configuraciones ",
    "Show hidden files" : "Mostrar archivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">acceder tus archivos vía WebDAV</a>",
    "Uploading @" : "Actualizando @",
    "No files in here" : "No hay archivos aquí",
    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "La carga es demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
    "Shared with you" : "Compartido con usted",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por liga",
    "Tags" : "Etiquetas",
    "Deleted files" : "Archivos borrados",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
    "Uploading..." : "Cargando...",
    "..." : "...",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["falta {hours}:{minutes}:{seconds} hora","faltan {hours}:{minutes}:{seconds} horas"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["falta {minutes}:{seconds} minuto","faltan {minutes}:{seconds} minutos"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["falta {seconds} segundo","faltan {seconds} segundos"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En cualquier momento...",
    "Soon..." : "Pronto...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La carga del archivo está en curso. El salir de la página ahora, la cancelará. ",
    "Move" : "Mover",
    "Copy local link" : "Copiar liga local",
    "Folder" : "Carpeta",
    "Upload" : "Cargar",
    "A new file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>borrado</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
    "No favorites" : "No hay favoritos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/es_MX.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
    "Storage invalid" : "El almacenamiento es inválido",
    "Unknown error" : "Se presentó un error desconocido",
    "All files" : "Todos los archivos",
    "Recent" : "Reciente",
    "File could not be found" : "No fue posible encontrar el archivo",
    "Home" : "Inicio",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "No fue posible crear la carpeta \"{dir}\"",
    "Upload cancelled." : "Carga cancelada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No fue posible cargar {filename} ya que es una carpeta o tiene un tamaño de 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No tienes suficiente espacio disponible, Estas cargando {size1} pero sólo cuentas con {size2} disponible",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta destino \"{dir}\" ya no existe",
    "Not enough free space" : "No cuentas con suficiente espacio libre",
    "Uploading …" : "Cargando...",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Move or copy" : "Mover o copiar",
    "Target folder" : "Carpeta destino",
    "Delete" : "Borrar",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Unshare" : "Dejar de compartir",
    "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No fue posible determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
    "Could not copy \"{file}\", target exists" : "No se pudo copiar \"{file}\", el destino ya existe",
    "Could not copy \"{file}\"" : "No se pudo copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} fue copiado dentro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} y otros {nbfiles} archivos fueron copiados dentro de {destination}",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
    "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n escondido","incluyendo %n ocultos"],
    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos"],
    "New" : "Nuevo",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El espacio de {owner} está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El espacio de {owner} está casi lleno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tu espacio está casi lleno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincide '{filter}'","coincidencia '{filter}'"],
    "View in folder" : "Ver en la carpeta",
    "Copied!" : "¡Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "New folder" : "Carpeta nueva",
    "Upload file" : "Cargar archivo",
    "Not favorited" : "No es un favorito",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
    "Added to favorites" : "Agregado a los favoritos",
    "Removed from favorites" : "Eliminado de los favoritos",
    "You added {file} to your favorites" : "Agregaste {file} a tus favoritos",
    "You removed {file} from your favorites" : "Eliminaste {file} de tus favoritos",
    "File changes" : "Cambios al archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuario remoto\"",
    "You created {file}" : "Creaste {file}",
    "{user} created {file}" : "{user} creó {file}",
    "{file} was created in a public folder" : "{file} fue creado en una carpeta pública",
    "You changed {file}" : "Cambiaste {file}",
    "{user} changed {file}" : "{user} cambió {file}",
    "You deleted {file}" : "Borraste {file}",
    "{user} deleted {file}" : "{user} borró {file}",
    "You restored {file}" : "Restauraste {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Renombraste {oldfile} como {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renombró {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Moviste {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado </strong> o <strong>renombrado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>borrado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita las notificaciones de la creación y cambios a tus <strong>archivos favoritos</strong> <em>(sólo flujo)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Cargar (max. %s)",
    "File handling" : "Manejo de archivos",
    "Maximum upload size" : "Tamaño máximo de carga",
    "max. possible: " : "max. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tomar 5 minutos para que los cambios apliquen. ",
    "Missing permissions to edit from here." : "Faltan privilegios para editar desde aquí. ",
    "%s of %s used" : "%s de %s usado",
    "%s used" : "%s usado",
    "Settings" : "Configuraciones ",
    "Show hidden files" : "Mostrar archivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">acceder a tus Archivos vía WebDAV</a>",
    "Cancel upload" : "Cancelar carga",
    "No files in here" : "No hay archivos aquí",
    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "La carga es demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
    "Shared with you" : "Compartido con usted",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por liga",
    "Tags" : "Etiquetas",
    "Deleted files" : "Archivos borrados",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
    "Uploading..." : "Cargando...",
    "..." : "...",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["falta {hours}:{minutes}:{seconds} hora","faltan {hours}:{minutes}:{seconds} horas"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["falta {minutes}:{seconds} minuto","faltan {minutes}:{seconds} minutos"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["falta {seconds} segundo","faltan {seconds} segundos"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En cualquier momento...",
    "Soon..." : "Pronto...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La carga del archivo está en curso. El salir de la página ahora, la cancelará. ",
    "Move" : "Mover",
    "Copy local link" : "Copiar liga local",
    "Folder" : "Carpeta",
    "Upload" : "Cargar",
    "A new file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>borrado</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">acceder tus archivos vía WebDAV</a>",
    "No favorites" : "No hay favoritos"
},
"nplurals=2; plural=(n != 1);");
